==> mauticGIT-Test-20251212_104643.tar.gz: var/www/html/mauticGIT-Test/var/tmp/twig/ee/ee2985eb7b15830804eb01e26efd42cb.php <==
<?php

use Twig\Environment;
use Twig\Error\LoaderError;
use Twig\Error\RuntimeError;
use Twig\Extension\CoreExtension;
use Twig\Extension\SandboxExtension;
use Twig\Markup;
use Twig\Sandbox\SecurityError;
use Twig\Sandbox\SecurityNotAllowedTagError;
use Twig\Sandbox\SecurityNotAllowedFilterError;
use Twig\Sandbox\SecurityNotAllowedFunctionError;
use Twig\Source;
use Twig\Template;
use Twig\TemplateWrapper;

/* @bundles/CoreBundle/Exception/ErrorHandlerException.php */
class __TwigTemplate_ee80e238ccd431bd0e4b7ea1193bb705 extends Template
{
    private Source $source;
    /**
     * @var array<string, Template>
     */
    private array $macros = [];

    public function __construct(Environment $env)
    {
        parent::__construct($env);

        $this->source = $this->getSourceContext();

        $this->parent = false;

        $this->blocks = [
        ];
    }

    protected function doDisplay(array $context, array $blocks = []): iterable
    {
        $macros = $this->macros;
        // line 1
        yield "<?php

namespace Mautic\\CoreBundle\\Exception;

class ErrorHandlerException extends \\Exception
{
    /**
     * @param string \$message
     * @param bool   \$showMessage
     * @param int    \$code
     */
    public function __construct(
        \$message = '',
        protected \$showMessage = false,
        \$code = 0,
        \\Exception \$previous = null
    ) {
        parent::__construct(\$message, \$code, \$previous);
    }

    /**
     * @return bool
     */
    public function showMessage()
    {
        return \$this->showMessage;
    }
}
";
        yield from [];
    }

    /**
     * @codeCoverageIgnore
     */
    public function getTemplateName(): string
    {
        return "@bundles/CoreBundle/Exception/ErrorHandlerException.php";
    }

    /**
     * @codeCoverageIgnore
     */
    public function getDebugInfo(): array
    {
        return array (  42 => 1,);
    }

    public function getSourceContext(): Source
    {
        return new Source("", "@bundles/CoreBundle/Exception/ErrorHandlerException.php", "/var/www/mautic-ktn/app/bundles/CoreBundle/Exception/ErrorHandlerException.php");
    }
}

==> mauticGIT-Test-20260116_092227.tar.gz: var/www/html/mauticGIT-Test/var/tmp/twig/ee/ee2985eb7b15830804eb01e26efd42cb.php <==
<?php

use Twig\Environment;
use Twig\Error\LoaderError;
use Twig\Error\RuntimeError;
use Twig\Extension\CoreExtension;
use Twig\Extension\SandboxExtension;
use Twig\Markup;
use Twig\Sandbox\SecurityError;
use Twig\Sandbox\SecurityNotAllowedTagError;
use Twig\Sandbox\SecurityNotAllowedFilterError;
use Twig\Sandbox\SecurityNotAllowedFunctionError;
use Twig\Source;
use Twig\Template;
use Twig\TemplateWrapper;

/* @bundles/CoreBundle/Exception/ErrorHandlerException.php */
class __TwigTemplate_ee80e238ccd431bd0e4b7ea1193bb705 extends Template
{
    private Source $source;
    /**
     * @var array<string, Template>
     */
    private array $macros = [];

    public function __construct(Environment $env)
    {
        parent::__construct($env);

        $this->source = $this->getSourceContext();

        $this->parent = false;

        $this->blocks = [
        ];
    }

    protected function doDisplay(array $context, array $blocks = []): iterable
    {
        $macros = $this->macros;
        // line 1
        yield "<?php

namespace Mautic\\CoreBundle\\Exception;

class ErrorHandlerException extends \\Exception
{
    /**
     * @param string \$message
     * @param bool   \$showMessage
     * @param int    \$code
     */
    public function __construct(
        \$message = '',
        protected \$showMessage = false,
        \$code = 0,
        \\Exception \$previous = null
    ) {
        parent::__construct(\$message, \$code, \$previous);
    }

    /**
     * @return bool
     */
    public function showMessage()
    {
        return \$this->showMessage;
    }
}
";
        yield from [];
    }

    /**
     * @codeCoverageIgnore
     */
    public function getTemplateName(): string
    {
        return "@bundles/CoreBundle/Exception/ErrorHandlerException.php";
    }

    /**
     * @codeCoverageIgnore
     */
    public function getDebugInfo(): array
    {
        return array (  42 => 1,);
    }

    public function getSourceContext(): Source
    {
        return new Source("", "@bundles/CoreBundle/Exception/ErrorHandlerException.php", "/var/www/html/mauticGIT-Test/app/bundles/CoreBundle/Exception/ErrorHandlerException.php");
    }
}
